BatchDeleteChunksRequest class final

Request to batch delete Chunks.

Constructors

BatchDeleteChunksRequest({String parent = '', required List<DeleteChunkRequest> requests})
BatchDeleteChunksRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent → String
Optional. The name of the Document containing the Chunks to delete. The parent field in every DeleteChunkRequest must match this value. Example: corpora/my-corpus-123/documents/the-doc-abc
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requests → List<DeleteChunkRequest>
Required. The request messages specifying the Chunks to delete.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String