BatchEmbedContentsRequest class final

Batch request to get embeddings from the model for a list of prompts.

Constructors

BatchEmbedContentsRequest({required String model, required List<EmbedContentRequest> requests})
BatchEmbedContentsRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
model → String
Required. The model's resource name. This serves as an ID for the Model to use.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requests → List<EmbedContentRequest>
Required. Embed requests for the batch. The model in each of these requests must match the model specified BatchEmbedContentsRequest.model.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String