DeleteDocumentRequest class final

Request to delete a Document.

Constructors

DeleteDocumentRequest({required String name, bool force = false})
DeleteDocumentRequest.fromJson(Object? j)
factory

Properties

force → bool
Optional. If set to true, any Chunks and objects related to this Document will also be deleted.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Required. The resource name of the Document to delete. Example: corpora/my-corpus-123/documents/the-doc-abc
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String