GenerateMessageResponse class final

The response from the model.

This includes candidate messages and conversation history in the form of chronologically-ordered messages.

Constructors

GenerateMessageResponse({List<Message> candidates = const [], List<Message> messages = const [], List<ContentFilter> filters = const []})
GenerateMessageResponse.fromJson(Object? j)
factory

Properties

candidates → List<Message>
Candidate response messages from the model.
final
filters → List<ContentFilter>
A set of content filtering metadata for the prompt and response text.
final
hashCode → int
The hash code for this object.
no setterinherited
messages → List<Message>
The conversation history used by the model.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String