GenerateTextResponse class final

The response from the model, including candidate completions.

Constructors

GenerateTextResponse({List<TextCompletion> candidates = const [], List<ContentFilter> filters = const [], List<SafetyFeedback> safetyFeedback = const []})
GenerateTextResponse.fromJson(Object? j)
factory

Properties

candidates → List<TextCompletion>
Candidate responses from the model.
final
filters → List<ContentFilter>
A set of content filtering metadata for the prompt and response text.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safetyFeedback → List<SafetyFeedback>
Returns any safety feedback related to content filtering.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String