GroundingSupport class final

Grounding support.

Constructors

GroundingSupport({Segment? segment, List<int> groundingChunkIndices = const [], List<double> confidenceScores = const []})
GroundingSupport.fromJson(Object? j)
factory

Properties

confidenceScores → List<double>
Confidence score of the support references. Ranges from 0 to 1. 1 is the most confident. This list must have the same size as the grounding_chunk_indices.
final
groundingChunkIndices → List<int>
A list of indices (into 'grounding_chunk') specifying the citations associated with the claim. For instance 1,3,4 means that grounding_chunk1, grounding_chunk3, grounding_chunk4 are the retrieved content attributed to the claim.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segment → Segment?
Segment of the content this support belongs to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String