ListChunksResponse class final

Response from ListChunks containing a paginated list of Chunks. The Chunks are sorted by ascending chunk.create_time.

Constructors

ListChunksResponse({List<Chunk> chunks = const [], String nextPageToken = ''})
ListChunksResponse.fromJson(Object? j)
factory

Properties

chunks → List<Chunk>
The returned Chunks.
final
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken → String
A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no more pages.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String