ListFilesRequest class final

Request for ListFiles.

Constructors

ListFilesRequest({int pageSize = 0, String pageToken = ''})
ListFilesRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pageSize → int
Optional. Maximum number of Files to return per page. If unspecified, defaults to 10. Maximum page_size is 100.
final
pageToken → String
Optional. A page token from a previous ListFiles call.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String