LogprobsResult class final

Logprobs Result

Constructors

LogprobsResult({double? logProbabilitySum, List<LogprobsResult_TopCandidates> topCandidates = const [], List<LogprobsResult_Candidate> chosenCandidates = const []})
LogprobsResult.fromJson(Object? j)
factory

Properties

chosenCandidates → List<LogprobsResult_Candidate>
Length = total number of decoding steps. The chosen candidates may or may not be in top_candidates.
final
hashCode → int
The hash code for this object.
no setterinherited
logProbabilitySum → double?
Sum of log probabilities for all tokens.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topCandidates → List<LogprobsResult_TopCandidates>
Length = total number of decoding steps.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String