PermissionService class final

Provides methods for managing permissions to PaLM API resources.

Implementers

Constructors

PermissionService({required Client client, Uri? endPoint, String? gcclVersion})
Creates a PermissionService using client for transport.
PermissionService.fromApiKey([String? apiKey])
Creates a PermissionService that does authentication through an API key.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelOperation(CancelOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
close() → void
Closes the client and cleans up any resources associated with it.
createPermission(CreatePermissionRequest request) → Future<Permission>
Create a permission to a specific resource.
deleteOperation(DeleteOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
deletePermission(DeletePermissionRequest request) → Future<void>
Deletes the permission.
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) → Future<Operation<T, S>>
Provides the Operations service functionality in this service.
getPermission(GetPermissionRequest request) → Future<Permission>
Gets information about a specific Permission.
listOperations(ListOperationsRequest request) → Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
listPermissions(ListPermissionsRequest request) → Future<ListPermissionsResponse>
Lists permissions for the specific resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transferOwnership(TransferOwnershipRequest request) → Future<TransferOwnershipResponse>
Transfers ownership of the tuned model. This is the only way to change ownership of the tuned model. The current owner will be downgraded to writer role.
updatePermission(UpdatePermissionRequest request) → Future<Permission>
Updates the permission.

Operators

operator ==(Object other) → bool
The equality operator.
inherited