Permission_Role class final

Defines the role granted by this permission.

Constructors

Permission_Role(String value)
const
Permission_Role.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const Permission_Role
The default value for Permission_Role.
owner → const Permission_Role
Owner can use, update, share and delete the resource.
reader → const Permission_Role
Reader can use the resource.
roleUnspecified → const Permission_Role
The default value. This value is unused.
writer → const Permission_Role
Writer can use, update and share the resource.