Segment class final

Segment of the content.

Constructors

Segment({int partIndex = 0, int startIndex = 0, int endIndex = 0, String text = ''})
Segment.fromJson(Object? j)
factory

Properties

endIndex → int
Output only. End index in the given Part, measured in bytes. Offset from the start of the Part, exclusive, starting at zero.
final
hashCode → int
The hash code for this object.
no setterinherited
partIndex → int
Output only. The index of a Part object within its parent Content object.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startIndex → int
Output only. Start index in the given Part, measured in bytes. Offset from the start of the Part, inclusive, starting at zero.
final
text → String
Output only. The text corresponding to the segment from the response.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String