TunedModel class final

A fine-tuned model created using ModelService.CreateTunedModel.

Constructors

TunedModel({TunedModelSource? tunedModelSource, String? baseModel, String name = '', String displayName = '', String description = '', double? temperature, double? topP, int? topK, TunedModel_State state = TunedModel_State.$default, Timestamp? createTime, Timestamp? updateTime, required TuningTask? tuningTask, List<int> readerProjectNumbers = const []})
TunedModel.fromJson(Object? j)
factory

Properties

baseModel → String?
Immutable. The name of the Model to tune. Example: models/gemini-1.5-flash-001
final
createTime → Timestamp?
Output only. The timestamp when this model was created.
final
description → String
Optional. A short description of this model.
final
displayName → String
Optional. The name to display for this model in user interfaces. The display name must be up to 40 characters including spaces.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Output only. The tuned model name. A unique name will be generated on create. Example: tunedModels/az2mb0bpw6i If display_name is set on create, the id portion of the name will be set by concatenating the words of the display_name with hyphens and adding a random portion for uniqueness.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
readerProjectNumbers → List<int>
Optional. List of project numbers that have read access to the tuned model.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → TunedModel_State
Output only. The state of the tuned model.
final
temperature → double?
Optional. Controls the randomness of the output.
final
topK → int?
Optional. For Top-k sampling.
final
topP → double?
Optional. For Nucleus sampling.
final
tunedModelSource → TunedModelSource?
Optional. TunedModel to use as the starting point for training the new model.
final
tuningTask → TuningTask?
Required. The tuning task that creates the tuned model.
final
updateTime → Timestamp?
Output only. The timestamp when this model was updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String