UpdateCorpusRequest class final

Request to update a Corpus.

Constructors

UpdateCorpusRequest({required Corpus? corpus, required FieldMask? updateMask})
UpdateCorpusRequest.fromJson(Object? j)
factory

Properties

corpus → Corpus?
Required. The Corpus to update.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateMask → FieldMask?
Required. The list of fields to update. Currently, this only supports updating display_name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String