UrlMetadata_UrlRetrievalStatus class final

Status of the url retrieval.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const UrlMetadata_UrlRetrievalStatus
The default value for UrlMetadata_UrlRetrievalStatus.
urlRetrievalStatusError → const UrlMetadata_UrlRetrievalStatus
Url retrieval is failed due to error.
urlRetrievalStatusPaywall → const UrlMetadata_UrlRetrievalStatus
Url retrieval is failed because the content is behind paywall.
urlRetrievalStatusSuccess → const UrlMetadata_UrlRetrievalStatus
Url retrieval is successful.
urlRetrievalStatusUnsafe → const UrlMetadata_UrlRetrievalStatus
Url retrieval is failed because the content is unsafe.
urlRetrievalStatusUnspecified → const UrlMetadata_UrlRetrievalStatus
Default value. This value is unused.