reviewSnippets property
Snippets of reviews that are used to generate answers about the features of a given place in Google Maps.
Implementation
final List<GroundingChunk_Maps_PlaceAnswerSources_ReviewSnippet>
reviewSnippets;
Snippets of reviews that are used to generate answers about the features of a given place in Google Maps.
final List<GroundingChunk_Maps_PlaceAnswerSources_ReviewSnippet>
reviewSnippets;